pyriskadjust.icd\_mapping package
=================================

Submodules
----------

pyriskadjust.icd\_mapping.mapping\_2018\_v21 module
---------------------------------------------------

.. automodule:: pyriskadjust.icd_mapping.mapping_2018_v21
    :members:
    :undoc-members:
    :show-inheritance:

pyriskadjust.icd\_mapping.mapping\_2018\_v22 module
---------------------------------------------------

.. automodule:: pyriskadjust.icd_mapping.mapping_2018_v22
    :members:
    :undoc-members:
    :show-inheritance:

pyriskadjust.icd\_mapping.mapping\_2019\_v23 module
---------------------------------------------------

.. automodule:: pyriskadjust.icd_mapping.mapping_2019_v23
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyriskadjust.icd_mapping
    :members:
    :undoc-members:
    :show-inheritance:
